package com.qmth.teachcloud.report.business.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.qmth.teachcloud.report.business.bean.result.InspectCollegeResult;
import com.qmth.teachcloud.report.business.bean.result.TBExamStudentResult;
import com.qmth.teachcloud.report.business.bean.result.TeachCollegeResult;
import com.qmth.teachcloud.report.business.entity.TBExamStudent;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;

/**
 * <p>
 * 考生表 服务类
 * </p>
 *
 * @author wangliang
 * @since 2021-06-01
 */
public interface TBExamStudentService extends IService<TBExamStudent> {

    /**
     * 查询开课学院列表
     *
     * @param examId
     * @param courseCode
     * @return
     */
    List<TBExamStudentResult> selectTeachCollegeList(Long schoolId, Long examId, String courseCode);

    /**
     * 查询考察学院列表
     *
     * @param schoolId
     * @param examId
     * @param courseCode
     * @return
     */
    List<TBExamStudentResult> selectInspectCollegeList(Long schoolId, Long examId, String courseCode);

    /**
     * 查询老师列表
     *
     * @param schoolId
     * @param examId
     * @param courseCode
     * @return
     */
    List<TBExamStudentResult> selectTeachList(Long schoolId, Long examId, String courseCode);

    /**
     * 查询班级列表
     *
     * @param schoolId
     * @param examId
     * @param courseCode
     * @return
     */
    List<TBExamStudentResult> selectClassList(Long schoolId, Long examId, String courseCode);

    /**
     * 开课成绩查询
     *
     * @param semester
     * @param examId
     * @param courseCode
     * @param current
     * @param inspectCollegeId
     * @param teacherId
     * @param studentParam
     * @param pageNumber
     * @param pageSize
     * @return
     */
    IPage<TeachCollegeResult> listTeachCollegeResult(String semester, Long examId, String courseCode, Boolean current, Long inspectCollegeId, Long teacherId, String studentParam, Integer pageNumber, Integer pageSize);

    /**
     * 导入异常考试类型
     * @param examId
     * @param file
     * @throws IOException
     * @throws NoSuchFieldException
     */
    void importFile(Long examId, MultipartFile file) throws IOException, NoSuchFieldException;

    /**
     * 开课成绩查询-导出查询结果
     *
     * @param semester
     * @param examId
     * @param courseCode
     * @param current
     * @param inspectCollegeId
     * @param teacherId
     * @param studentParam
     * @param response
     * @throws Exception
     */
    void exportTeachCollegeResult(String semester, Long examId, String courseCode, Boolean current, Long inspectCollegeId, Long teacherId, String studentParam, HttpServletResponse response) throws Exception;

    /**
     * 考查成绩查询
     *
     * @param semester
     * @param examId
     * @param courseCode
     * @param current
     * @param teachCollegeId
     * @param teacherId
     * @param studentParam
     * @param pageNumber
     * @param pageSize
     * @return
     */
    IPage<InspectCollegeResult> listInspectCollegeResult(String semester, Long examId, String courseCode, Boolean current, Long teachCollegeId, Long teacherId, String studentParam, Integer pageNumber, Integer pageSize);

    /**
     * 考查成绩查询-导出查询结果
     *
     * @param semester
     * @param examId
     * @param courseCode
     * @param current
     * @param teachCollegeId
     * @param teacherId
     * @param studentParam
     * @param response
     */
    void exportInspectCollegeResult(String semester, Long examId, String courseCode, Boolean current, Long teachCollegeId, Long teacherId, String studentParam, HttpServletResponse response) throws Exception;
}
